Annoyances experienced while building this
==========================================

This turned out to be a huge chore to build, due to a number of issues I
have with how requirejs took on configuration.

No consistent treatment of paths
No consistent treatment of paths

